#include <stdio.h>
#include <stdlib.h>

// we need stdlib.h for malloc and free

int main( int argc, char** argv )
{
	int* A = NULL;
	int i = 0, arraySize = 0;

	// note that argv[0] is always the name of executable
	// and argc is >= 1

	// we expect 1 user argument
	if( argc != 2 )
	{
		printf( "usage : %s number\n", argv[0] );
		return 1;
	}

	arraySize = atoi( argv[1] );

	// error checking. 
	if( arraySize < 2 )
	{
		printf( "array size must be larger than 2\n" );
		return 1;
	}

	A = (int*)malloc( sizeof( int ) * arraySize );

	/* or we can do this.

	A = int[arraySize];

	this is identical to the malloc way 
	except that you don't need to(shouldn't) free A. */

	// malloc returns NULL if memory allocation fails.
	if( A == NULL )
	{
		printf( "failed to allocate memory\n" );
		return 1;
	}

	A[0] = 0;
	A[1] = 1;

	for( i = 2; i < arraySize; i++ )
	{
		A[i] = A[i-2] + A[i-1];

		/* or we can use pointer arithmetics as below.

		*(A+i) = *(A+i-2) + *(A+i-1);

		both lines are identical */
	}

	for( i = 0; i < arraySize; i++ )
	{
		printf( "%d,", A[i] );

		/* or we can use pointer arithmetics as below.

		printf( "%d,", *(A+i) );

		both lines are identical */
	}

	printf( "\n" );

	// we know that A not NULL as we already checked it above. 
	// note that you should never free if you declared A 
	// without using malloc.
	free( A );
}
